@@ -72,8 +72,8 @@ impl Config {
             "-C".to_string(),
             "link-arg=--lld-path=/usr/bin/mold".to_string(),
         ];
-        
-         let linker_flag_mac = vec![
+
+        let linker_flag_mac = vec![
             "-C".to_string(),
             "link-arg=--lld-path=/usr/bin/zld".to_string(),
         ];
@@ -98,34 +98,32 @@ impl Config {
     }
 
     pub fn faster_nightly(&mut self, name: Option<&String>) -> bool {
-        if let Err(err) = fs::remove_file("rust-toolchain.toml") {
-            if err.kind() == ErrorKind::NotFound {
-            } else {
-                println!("FILE_ACCESS denied");
-                return false;
-            }
-        }
         let linker = "/usr/bin/clang".to_string();
         let linker_flag = vec![
             "-C".to_string(),
             "link-arg=--lld-path=/usr/bin/mold".to_string(),
         ];
 
+        let linker_flag_mac = vec![
+            "-C".to_string(),
+            "link-arg=--lld-path=/usr/bin/zld".to_string(),
+        ];
+
         self.target_linux_gnu = Target {
             linker: linker.clone(),
             rustflags: linker_flag.clone(),
         };
         self.target_linux_musl = Target {
             linker: linker.clone(),
-            rustflags: linker_flag.clone(),
+            rustflags: linker_flag,
         };
         self.target_macos_intel = Target {
             linker: linker.clone(),
-            rustflags: linker_flag.clone(),
+            rustflags: linker_flag_mac.clone(),
         };
         self.target_macos_arm = Target {
             linker,
-            rustflags: linker_flag,
+            rustflags: linker_flag_mac,
         };
 
         self.build = Build {
@@ -137,6 +135,12 @@ impl Config {
     }
 
     fn write_all(&self, tlc: bool, name: Option<&String>) -> Result<()> {
+        if let Err(err) = fs::remove_file("rust-toolchain.toml") {
+            if err.kind() == ErrorKind::NotFound {
+            } else {
+                return Err(anyhow::Error::new(err));
+            }
+        }
         let project_path = match name {
             Some(name) => std::env::current_dir().unwrap().join(name),
             None => std::env::current_dir().unwrap(),
